The nematic and ferronematic order parameters can be used to distinguish the isotropic,
nematic and ferronematic phases of liquid crystals.

The nematic order parameter S characterizes the orientational order of molecules
and ranges from S=0 (isotropic) to S=1 (all molecular axes are perfectly parallel).
Most liquids are isotropic, as there is no preferred direction, and have an order parameter
close to 0. In liquid crystals, membranes and solids, molecules tend to align giving
rise to order parameters closer to 1.

$S$ is calculated from the distribution of the angles between the molecular axes ($\hat{u}_i$ for $i=1,\ldots,N$)
and the nematic director $\hat{n}$,
$$
S = \frac{1}{N} \sum_{i=1}^N \left(\frac{3}{2} \cos^2(\theta_i) - \frac{1}{2} \right),
$$
with $\cos(\theta_i) = \hat{n} \cdot \hat{u}_i$.

The ferronematic order parameter P depends on the relative orientations of the molecular
axes. If the axes all point into the same direction, giving rise to a net polarization if
the molecules have permanent dipole moments, P is close to 1. If the molecular axes are
oriented isotropically or are aligned antiparallel so that there is no net polarization,
P is close 0.

$P$ is length of the average of the molecular axes ($\hat{u}_i$ for $i=1,\ldots,N$)
$$
P = \vert \frac{1}{N} \sum_{i=1}^N \hat{u}_i \vert
$$
Since the molecular axes are unit vectors, P ranges from a minimum of 0 to a maximum of 1.

By adding a bias to the (ferro)nematic order parameter, one can drive a liquid crystal from the
isotropic to the (ferro)nematic phase.
